// File **********OC3.C***********
// Periodic Interrupt using TOC3

//  This example accompanies the books
//   "Embedded Microcomputer Systems: Real Time Interfacing", Brooks-Cole, copyright (c) 2000,
//   "Introduction to Embedded Microcomputer Systems: 
//    Motorola 6811 and 6812 Simulation", Brooks-Cole, copyright (c) 2002,
//    Jonathan W. Valvano 2/17/04

// You may use, edit, run or distribute this file 
//    as long as the above copyright notices remain 
#include <mc68hc812a4.h>     /* derivative information */

 
unsigned short static volatile Count;
unsigned short static Period;
void (*CallBack)(void);  // call back function
#define RATE 1000  

interrupt 11 void TOC3handler(void){ // executes at 1000 Hz 
  TFLG1 = 0x08;         // acknowledge OC3
  Count++;
  TC3 = TC3+RATE;       // 1 ms
  if(Count==Period){
    Count = 0;
    (*CallBack)();      // execute call back process
  } 
}

//---------------------OC_Start---------------------
// arm output compare 3 for 1000Hz periodic interrupt
// Input: thePeriod is a time period in ms
//        fp is a function to be executed at this period
// Output: none 
// example
//   void toggle(void){PORTT^=0x40;}
//   OC_Start(100,&toggle);
void OC_Start(unsigned short thePeriod, void(*fp)(void)){
  asm sei      // make ritual atomic 
  Period = thePeriod;
  CallBack = fp;
  Count  = 0;
  TIOS  |= 0x08;    // activate TC3 as output compare
  TSCR   = 0x80;    // activate timer
  TMSK2  = 0x33;    // clock at 1MHz    
  TMSK1 |= 0x08;    // arm OC3
  TC3    = TCNT+50; // first interrupt right away
  asm cli
}
