// filename ******** Main.C ************** 
// Example main program for output compare interrupt example   
// stepper connected to PH3,PH2,PH1,PH0
//    Jonathan W. Valvano 2/17/04

#include <hidef.h>      /* common defines and macros */
#include <mc68hc812a4.h>     /* derivative information */

#pragma LINK_INFO DERIVATIVE "hc12a4"

#include "oc3.h"
const struct State{
  unsigned char Out;      /* Output to Port H */
  const struct State *Next;  
};
typedef const struct State StateType;
typedef StateType *	StatePtr;
StatePtr Pt;  /* Current State */
#define S5  &FSM[0]
#define S6  &FSM[1]
#define S10 &FSM[2]
#define S9  &FSM[3]
StateType FSM[4]={
  {0x05,S6},
  {0x06,S10},
  {0x0A,S9},
  {0x09,S5}
};

//---------------------step---------------------
// move stepper motor one step
// Input: none
// Output: none
// errors there must be a delay between calls
void step(void){
  PORTH = (PORTH&0xF0)+Pt->Out;
  Pt = Pt->Next;
  PORTT ^= 0x40;
}

void main(void) {
  Pt = S5;         // Initial State 
  COPCTL = 0x00;   // disable COP 
  DDRT |= 0x40;    // PortT bit 6 is an output to an LED
  DDRH = 0xFF;     // stepper connected to PH3,PH2,PH1,PH0
  OC_Start(10,&step);	 // step motor every 10ms
  for(;;) {} /* wait forever */
}
